AppsentrikSdkPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- AppsentrikSdkPlatform
- Implementers
Constructors
- AppsentrikSdkPlatform()
- Constructs a AppsentrikSdkPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getDeviceContext(
) → Future< Map< String, dynamic> ?> - Returns device/OS context for Dart-level crashes.
-
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setCurrentAppsentrikId(
String appsentrikId) → Future< void> - Inform native side about the current appsentrik_id so that native crashes can be tagged with the same logical user.
-
setCurrentSessionId(
String sessionId) → Future< void> - Inform native side about the current session ID so that native crashes can be tagged with the same session.
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadNativeCrashes(
{required String publicKey, required String baseUrl, required String environment, required String appVersion, Map< String, dynamic> ? user}) → Future<void> - Upload any pending native OS-level crashes (Android/iOS).
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ AppsentrikSdkPlatform
-
getter/setter pair