AppsentrikSdkWeb class
A web implementation of the AppsentrikSdkPlatform of the AppsentrikSdk plugin.
- Inheritance
-
- Object
- PlatformInterface
- AppsentrikSdkPlatform
- AppsentrikSdkWeb
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getDeviceContext(
) → Future< Map< String, dynamic> ?> -
Returns device/OS context for Dart-level crashes.
override
-
getPlatformVersion(
) → Future< String?> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setCurrentAppsentrikId(
String appsentrikId) → Future< void> -
Inform native side about the current appsentrik_id so that
native crashes can be tagged with the same logical user.
override
-
setCurrentSessionId(
String sessionId) → Future< void> -
Inform native side about the current session ID so that
native crashes can be tagged with the same session.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadNativeCrashes(
{required String publicKey, required String baseUrl, required String environment, required String appVersion, Map< String, dynamic> ? user}) → Future<void> -
Upload any pending native OS-level crashes (Android/iOS).
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void